@@ -1,5 +1,5 @@
 package WebService::Braintree;
-$WebService::Braintree::VERSION = '0.8';
+$WebService::Braintree::VERSION = '0.9';
 use strict;
 use warnings;
 use WebService::Braintree::Address;
@@ -65,7 +65,7 @@ sub configuration { return $configuration_instance; }
 =head2 ISSUES
 
 The bugtracker is at
-L<https://github.com/webservice/braintree_perl/issues>.
+L<https://github.com/singingfish/braintree_perl/issues>.
 
 Patches welcome!
 
